@@ -1,7 +1,7 @@
-#!/usr/bin/python
-# vim: set fileencoding=utf8:
+#!/usr/bin/python3
+# vim: set fileencoding=utf-8:
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007, 2008, 2011  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007, 2008, 2011, 2016  Tom Cato Amundsen
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,10 +18,10 @@
 
 # This script is used to launch Solfege when running
 # it from the source dir without installing.
-from __future__ import absolute_import
-import __builtin__
+
+import builtins
 import time
-__builtin__.start_time = time.time()
+builtins.start_time = time.time()
 
 import sys
 import os
@@ -44,8 +44,8 @@ if sys.platform == 'win32':
             if os.path.exists(os.path.join(filesystem.get_home_dir(), ".solfegerc")):
                 shutil.copy(os.path.join(filesystem.get_home_dir(), ".solfegerc"),
                             filesystem.rcfile())
-    except (IOError, os.error), e:
-        print "Migration failed:", e
+    except (IOError, os.error) as e:
+        print("Migration failed:", e)
 
 from solfege import presetup
 presetup.presetup("default.config", None, filesystem.rcfile())
