@@ -2,5 +2,4 @@
 import os
 __all__ = [os.path.splitext(fn)[0]
         for fn in os.listdir(os.path.join(*__name__.split(".")))
-           if fn.endswith(".py") and fn != u"__init__.py" and fn != u"tuner.py"]
-
+           if fn.endswith(".py") and fn != "__init__.py" and fn != "tuner.py"]
