@@ -1,6 +1,6 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # Solfege - free ear training software
-# Copyright (C) 2007, 2008, 2011 Tom Cato Amundsen
+# Copyright (C) 2007, 2008, 2011, 2016 Tom Cato Amundsen
 # License is GPL, see file COPYING
 
 from __future__ import absolute_import
@@ -11,13 +11,15 @@ import shutil
 import atexit
 
 # we need this hack because doctest messes with _
+
+
 def f(s):
-    if type(s) == type(""):
-        print "'%s'" % s
+    if isinstance(s, str):
+        print ("'%s'" % s)
     elif s is None:
         return
     else:
-        print s
+        print (s)
 
 sys.__displayhook__ = f
 
@@ -69,6 +71,7 @@ suite = unittest.TestSuite((
     solfege.tests.test_cfg.suite,
 ))
 
+
 class MyProg(unittest.TestProgram):
     USAGE = """\
 Usage: %(progName)s [options] [test] [...]
@@ -93,6 +96,7 @@ def iter_suite(suite):
         else:
             yield t
 
+
 def rmtemp():
     shutil.rmtree(testlib.outdir)
     if os.path.exists(testlib.TmpFileBase.tmpdir):
@@ -104,7 +108,6 @@ testlib.TmpFileBase.tmpdir
 if not os.path.exists(testlib.TmpFileBase.tmpdir):
     os.makedirs(testlib.TmpFileBase.tmpdir)
 
-
 args = [x for x in sys.argv[1:] if x not in ('-v', '-q', '-h')]
 if args and '-h' not in sys.argv:
     new_suite = unittest.TestSuite()
@@ -120,4 +123,3 @@ if args and '-h' not in sys.argv:
 sys.argv.append("suite")
 
 MyProg()
-
