@@ -1,12 +1,12 @@
-#!/usr/bin/env python
+#!/usr/bin/python2.3
+
 import sys, os
-if os.getcwd()[-4:] == "test":
+if os.getcwdu()[-4:] == "test":
     sys.path.insert(0, "..")
 else:
     sys.path.insert(0, ".")
 import soundcard
-soundcard.initialise("/dev/sequencer2", 0)
-#soundcard.initialise("/dev/sequencer", 0)
+soundcard.initialise_devicefile("/dev/sequencer2", 2)
 
 s = soundcard.solfege_c_midi
 
@@ -19,20 +19,19 @@ s.seq_start_timer()
 #s.seq_start_note(devnum, chan, 60, 90)
 #s.seq_stop_note(devnum, chan, 60, 90)
 
-#for i in range(500):
+# for i in range(500):
 #        s.seq_start_note(devnum, chan, 60 + i % 10, 90)
 #        s.seq_delta_time(25)
 #        s.seq_stop_note(devnum, chan, 60 + i % 10, 90)
 s.seq_set_patch(0, 0, 63)
 s.seq_set_patch(0, 1, 63)
 for i in range(500):
-        s.seq_start_note(devnum, 0, 60 + (i*2) % 10, 90)
+        s.seq_start_note(devnum, 0, 60 + (i * 2) % 10, 90)
         s.seq_delta_time(25)
-        s.seq_stop_note(devnum, 0, 60 + (i*2) % 10, 90)
-        s.seq_start_note(devnum, 1, 60 + (i*2) % 10 + 1, 90)
+        s.seq_stop_note(devnum, 0, 60 + (i * 2) % 10, 90)
+        s.seq_start_note(devnum, 1, 60 + (i * 2) % 10 + 1, 90)
         s.seq_delta_time(25)
-        s.seq_stop_note(devnum, 1, 60 + (i*2) % 10 + 1, 90)
-
+        s.seq_stop_note(devnum, 1, 60 + (i * 2) % 10 + 1, 90)
 
 
 s.seqbuf_dump()
