@@ -1,16 +1,17 @@
 #!/usr/bin/python
 import sys
 sys.path.insert(0, ".")
-import src.i18n
-src.i18n.setup(".", "C")
-import src.cfg
-import src.filesystem
-src.cfg.initialise("default.config", None, src.filesystem.rcfile())
-import soundcard
+from solfege import i18n
+i18n.setup(".", "C")
+from solfege import cfg
+from solfege import filesystem
+cfg.initialise("default.config", None, filesystem.rcfile())
+from solfege import soundcard
+from solfege.mpd import Track
 
-## This works nice with ALSA and OSS emulation with SB Live card:
-#soundcard.initialise_external_midiplayer("/usr/bin/timidity", False)
-soundcard.initialise_devicefile("/dev/sequencer2", 2)
+# This works nice with ALSA and OSS emulation with SB Live card:
+soundcard.initialise_external_midiplayer()
+#soundcard.initialise_devicefile("/dev/sequencer2", 2)
 
 
 print """
@@ -24,7 +25,7 @@ C       C       C_C_C   C
 Press enter when the sounds are finished.
 """
 
-t = soundcard.Track()
+t = Track()
 t.set_bpm(120, 4)
 t.note(4, 60, 100)
 t.note(4, 64, 100)
@@ -49,4 +50,4 @@ soundcard.synth.play_track(t)
 import sys
 print "press <enter>"
 sys.stdin.readline()
-#soundcard.synth.close()
+# soundcard.synth.close()
