@@ -1,5 +1,5 @@
-#!/usr/bin/python
-# Copyright (C) 2007, 2008 Tom Cato Amundsen
+#!/usr/bin/python3
+# Copyright (C) 2007, 2008, 2011, 2016 Tom Cato Amundsen
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -15,8 +15,6 @@
 
 # Undocumented
 # chordvoicing (test written)
-# example
-# harmonicprogressiondictation (test written)
 # identifybpm
 # singinterval
 # tuner
@@ -35,7 +33,6 @@
 # idbyname
 # singanswer
 # rhythmtapping
-# chord (obsolete)
 # idproperty
 # dictation
 # singchord
@@ -45,12 +42,10 @@ module_to_mtype = {
   'idbyname': ('voice', 'rvoice', 'chord', 'music'),
   'singanswer': ('voice', 'rvoice', 'chord', 'music'),
   'rhythmtapping': ('voice', 'rvoice'),
-  'chord': ('chord',),
   'idproperty': ('chord', 'rvoice',),
   'dictation': ('music', 'voice', 'rvoice',),
   'singchord': ('satb',),
   'elembuilder': ('voice', 'rvoice', 'music'),
-  'harmonicprogressiondictation': ('music', 'rvoice'),
   'chordvoicing': ('chord', 'satb'),
 }
 
@@ -105,24 +100,27 @@ errors = {
 }
 errors['rvoice'] = errors['voice']
 
+
 def set1():
     for module in module_to_mtype:
-        of = open("regression-lesson-files/xx-%s-exceptions" % module, "w")
+        of = open("exercises/standard/regression-lesson-files/xx-%s-exceptions" % module, "w")
+        def p(s):
+            print(s, file=of)
         if module == 'elembuilder':
-            print >> of, 'include("../lesson-files/include/progression-elements")'
-        print >> of, "header {"
-        print >> of, "  module = %s" % module
-        print >> of, '  title = "%s mpd errors"' % module
-        print >> of, "  lesson_id = \"%s-module-exceptions\"" % module
-        print >> of, "  have_repeat_slowly_button = yes"
+            p('include("../lesson-files/include/progression-elements")')
+        p("header {")
+        p("  module = %s" % module)
+        p('  title = "%s mpd errors"' % module)
+        p("  lesson_id = \"%s-module-exceptions\"" % module)
+        p("  have_repeat_slowly_button = yes")
         if module == 'idbyname':
-            print >> of, "  filldir = horiz"
-            print >> of, "  fillnum = 4"
+            p("  filldir = horiz")
+            p("  fillnum = 4")
         elif module == 'elembuilder':
-            print >> of, "  elements = auto"
+            p("  elements = auto")
         elif module == 'idproperty':
-            print >> of, '  flavour = "chord"'
-        print >> of, "}"
+            p('  flavour = "chord"')
+        p("}")
         for mtype in module_to_mtype[module]:
             if mtype == module_to_mtype[module][0]:
                 vv = [ok[mtype]]
@@ -130,15 +128,15 @@ def set1():
                 vv = []
             if mtype in errors:
                 for music in vv + errors[mtype]:
-                    print >> of, "question {"
-                    print >> of, '  name = "%s: %s"' % (mtype, music)
-                    print >> of, '  music = %s("%s")' % (mtype, music)
+                    p("question {")
+                    p('  name = "%s: %s"' % (mtype, music))
+                    p('  music = %s("%s")' % (mtype, music))
                     if module == 'singanswer':
-                        print >> of, 'question_text = "question..."'
-                        print >> of, 'answer = music %s("%s")' % (mtype, music)
+                        p('question_text = "question..."')
+                        p('answer = music %s("%s")' % (mtype, music))
                     elif module == 'elembuilder':
-                        print >> of, 'elements = progI, progIV'
-                    print >> of, "}"
+                        p('elements = progI, progIV')
+                    p("}")
         of.close()
 
 set1()
