@@ -16,22 +16,24 @@
 # unfinished script that create a lilypond-book document
 # over all the lessonfiles.
 
-import pygtk
-pygtk.require("2.0")
+import gi
+pyGtk.require("2.0")
 
 import sys, re, os, os.path
 sys.path.append(".")
 
-import src, src.dataparser, src.lessonfile
+import solfege, solfege.dataparser, solfege.lessonfile
+
 
 def tex_subst(s):
     return s.replace("&", "\&").replace("#", "\#")
 
+
 def so2ly(s, musicformat):
     re_staff = re.compile("\\\\staff")
     re_addvoice = re.compile("\\\\addvoice")
     v = re_staff.split(s)
-    v = filter(lambda i: i!="", v)
+    v = filter(lambda i: i != "", v)
     v = map(lambda s, r=re_addvoice: r.split(s), v)
     retval = "\\score{\n  <"
     i = ''
@@ -49,6 +51,7 @@ def so2ly(s, musicformat):
     retval = retval + "\n  >\n}"
     return retval
 
+
 def write_header(of, header, filename):
     of.write("\n\\subsection{%s}" % tex_subst(header.title))
     of.write("\n\\begin{itemize}")
@@ -58,6 +61,7 @@ def write_header(of, header, filename):
     of.write("\n\\item musicformat: %s" % header.musicformat)
     of.write("\n\\end{itemize}")
 
+
 def write_questions(of, header, questions):
     for q in questions:
         of.write("""'%s':
@@ -81,12 +85,13 @@ predef = {'dictation': 'dictation',
                       'no': 0,
                       'tempo': (60, 4)}
 
+
 def write_file(of, filename):
-    parser = src.dataparser.Dataparser(predef, ('tempo',))
+    parser = solfege.dataparser.Dataparser(predef, ('tempo',))
     parser.parse_file(filename)
 
     questions = filter(lambda e: e['blocktype'] == 'question', parser.m_blocks)
-    header = src.lessonfile._Header(
+    header = solfege.lessonfile._Header(
           filter(lambda e: e['blocktype'] == 'header', parser.m_blocks)[0])
 
     write_header(of, header, filename)
@@ -104,4 +109,3 @@ for filename in sys.argv[1:]:
 
 of.write("\n\\end{document}")
 of.close()
-
